import * as codebuild from 'aws-cdk-lib/aws-codebuild';
import * as ec2 from 'aws-cdk-lib/aws-ec2';
import * as iam from 'aws-cdk-lib/aws-iam';
import * as pipelines from 'aws-cdk-lib/pipelines';
import { Construct } from 'constructs';
import { CodeGuruSeverityThreshold } from '../common';
/**
 * Props for the CDKPipeline construct.
 */
export interface CDKPipelineProps extends PipelineProps {
    /**
     * The qualifier for the application.
     */
    readonly applicationQualifier: string;
    /**
     * The name of the pipeline.
     */
    readonly pipelineName: string;
    /**
     * Additional IAM policies to be attached to the pipeline role.
     */
    readonly rolePolicies?: iam.PolicyStatement[];
}
/**
 * Props for configuring a VPC.
 */
export interface VpcProps {
    /**
     * The VPC to be used.
     */
    readonly vpc: ec2.IVpc;
    /**
     * Proxy configuration.
     */
    readonly proxy?: ProxyProps;
}
/**
 * Props for configuring a proxy.
 */
export interface ProxyProps {
    /**
     * A list of URLs or IP addresses that should bypass the proxy.
     */
    readonly noProxy: string[];
    /**
     * The ARN of the secret containing the proxy credentials.
     */
    readonly proxySecretArn: string;
    /**
     * A URL to test the proxy configuration.
     */
    readonly proxyTestUrl: string;
}
export interface PipelineOptions {
    /**
     * Whether the pipeline should allow self-mutation.
     */
    readonly selfMutation?: boolean;
    /**
     * Publish assets in multiple CodeBuild projects
     *
     * If set to false, use one Project per type to publish all assets.
     *
     * Publishing in parallel improves concurrency and may reduce publishing
     * latency, but may also increase overall provisioning time of the CodeBuild
     * projects.
     *
     * Experiment and see what value works best for you.
     *
     * @default true
     */
    readonly publishAssetsInParallel?: boolean;
    /**
     * A list of credentials used to authenticate to Docker registries.
     *
     * Specify any credentials necessary within the pipeline to build, synth, update, or publish assets.
     *
     * @default []
     */
    readonly dockerCredentials?: pipelines.DockerCredential[];
    /**
     * Deploy every stack by creating a change set and executing it
     *
     * When enabled, creates a "Prepare" and "Execute" action for each stack. Disable
     * to deploy the stack in one pipeline action.
     *
     * @default true
     */
    readonly useChangeSets?: boolean;
}
/**
 * Props for configuring the pipeline.
 */
export interface PipelineProps {
    /**
     * The source repository for the pipeline.
     */
    readonly repositoryInput: pipelines.IFileSetProducer;
    /**
     * The branch to be used from the source repository.
     */
    readonly branch: string;
    /**
     * Whether Docker should be enabled for synth.
     * @default false
     */
    readonly isDockerEnabledForSynth?: boolean;
    /**
     * The Docker image to be used for the build project.
     */
    readonly buildImage?: codebuild.IBuildImage;
    /**
     * The severity threshold for CodeGuru security scans.
     */
    readonly codeGuruScanThreshold?: CodeGuruSeverityThreshold;
    /**
     * VPC configuration for the pipeline.
     */
    readonly vpcProps?: VpcProps;
    /**
     * Pipeline variables to be passed as environment variables.
     */
    readonly pipelineVariables?: {
        [key: string]: string;
    };
    /**
     * The primary output directory for the synth step.
     */
    readonly primaryOutputDirectory: string;
    /**
     * The CI commands to be executed as part of the Synth step.
     */
    readonly ciBuildSpec: codebuild.BuildSpec;
    /**
     * Additional install commands to be executed before the synth step.
     */
    readonly installCommands?: string[];
    /**
     * Default options for CodeBuild projects in the pipeline.
     */
    readonly codeBuildDefaults: pipelines.CodeBuildOptions;
    /**
     * Additional Pipeline options.
     */
    readonly options?: PipelineOptions;
}
/**
 * A construct for creating a CDK pipeline.
 */
export declare class CDKPipeline extends pipelines.CodePipeline {
    /**
     * Default install commands for the pipeline.
     */
    static readonly installCommands: string[];
    private readonly codeGuruScanThreshold?;
    private readonly applicationQualifier;
    private readonly pipelineName;
    /**
     * Creates a new instance of the CDKPipeline construct.
     * @param scope The parent construct.
     * @param id The ID of the construct.
     * @param props The props for configuring the pipeline.
     */
    constructor(scope: Construct, id: string, props: CDKPipelineProps);
    /**
     * Builds the pipeline by applying necessary configurations and suppressing certain CDK Nag rules.
     */
    buildPipeline(): void;
    /**
     * Applies the CodeGuru security scan step to the pipeline based on the provided severity threshold.
     * @param threshold The severity threshold for CodeGuru security scans.
     */
    private applyCodeGuruScan;
}
