import { Construct } from 'constructs';
import { IPipelineBlueprintProps } from '../../stacks';
import { IStage, Environment } from '../types/Types';
/**
 * Defines the scope of a resource provider.
 */
export declare enum Scope {
    /**
     * The resource provider will be available globally across all stages.
     */
    GLOBAL = "GLOBAL",
    /**
     * The resource provider will be available only within the current stage.
     */
    PER_STAGE = "PER_STAGE"
}
/**
 * Interface representing a generic resource provider.
 * Provides resources through the `provide` method.
 */
export interface IResourceProvider {
    /**
     * The scope in which the resource provider is available.
     * Defaults to `Scope.GLOBAL`.
     */
    scope?: Scope;
    /**
     * Provides resources based on the given context.
     *
     * @param context The context in which the resources are provided.
     * @returns The provided resources.
     */
    provide(context: ResourceContext): any;
}
/** @internal */
export interface ResourceProviderSupplier {
    resourceProviders: Map<string, IResourceProvider>;
}
/**
 * Provides an API to register resource providers and access the provided resources.
 */
export declare class ResourceContext {
    private _scope;
    readonly pipelineStack: Construct;
    readonly blueprintProps: IPipelineBlueprintProps;
    /**
     * Returns the singleton instance of ResourceContext.
     *
     * @returns The ResourceContext instance.
     */
    static instance(): ResourceContext;
    private static _instance;
    private readonly globalScope;
    private stagedScope?;
    private _currentStage;
    private _currentEnv?;
    /**
     * Constructs a new instance of ResourceContext.
     *
     * @param _scope The construct scope.
     * @param pipelineStack The pipeline stack construct.
     * @param blueprintProps The pipeline blueprint properties.
     */
    constructor(_scope: Construct, pipelineStack: Construct, blueprintProps: IPipelineBlueprintProps);
    /** @internal */
    _scoped(scopeToUse: Construct, block: () => any): any;
    /**
     * Initializes the current stage and its associated resource providers.
     *
     * @param stage The current stage.
     */
    initStage(stage: IStage): void;
    /**
     * Retrieves a resource by its name.
     *
     * @param name The name of the resource.
     * @returns The resource, or undefined if it doesn't exist.
     */
    get(name: string): any | undefined;
    /**
     * Checks if a resource with the given name exists.
     *
     * @param name The name of the resource.
     * @returns True if the resource exists, false otherwise.
     */
    has(name: string): boolean;
    add(name: string, value: any): void;
    /**
     * Retrieves the current stage.
     *
     * @returns The current stage.
     */
    get stage(): string;
    /**
     * Retrieves the current environment.
     *
     * @returns The current environment.
     */
    get environment(): Environment;
    /**
     * Retrieves the current construct scope.
     *
     * @returns The current construct scope.
     */
    get scope(): Construct;
}
/**
 * Enum representing global resources.
 */
export declare enum GlobalResources {
    REPOSITORY = "repository",
    VPC = "vpc",
    PROXY = "proxy",
    ENCRYPTION = "encryption",
    PARAMETER_STORE = "parameter-store",
    STAGE_PROVIDER = "stage-provider",
    CODEBUILD_FACTORY = "codebuild-factory",
    COMPLIANCE_BUCKET = "compliance-bucket",
    PIPELINE = "pipeline",
    PHASE = "phase",
    HOOK = "hook",
    ADDON_STORE = "addon-store",
    CI_DEFINITION = "ci-definition",
    LOGGING = "logging"
}
