import * as cdk from 'aws-cdk-lib';
import * as kms from 'aws-cdk-lib/aws-kms';
import { Step } from 'aws-cdk-lib/pipelines';
import { Construct } from 'constructs';
import { IPipelineConfig, IStackProvider, ResourceContext } from '../';
/**
 * Abstract base class for providing stacks to a deployment pipeline.
 * This class implements the IStackProvider interface and provides default implementation
 * for providing deployment hook configurations (pre and post hooks) and accessing context properties.
 */
export declare abstract class BaseStackProvider implements IStackProvider {
    private _context?;
    private _scope?;
    private _env?;
    private _stageName?;
    private _applicationName?;
    private _applicationQualifier?;
    private _properties?;
    private _encryptionKey?;
    /**
     * Provides the deployment hook configuration for this stack provider.
     * @param context The resource context containing the scope, stage, environment, and blueprint properties.
     */
    provide(context: ResourceContext): void;
    /**
     * Returns the pre-deployment hook steps for this stack provider.
     * @returns An array of pre-deployment hook steps.
     */
    protected preHooks(): Step[];
    /**
     * Returns the post-deployment hook steps for this stack provider.
     * @returns An array of post-deployment hook steps.
     */
    protected postHooks(): Step[];
    /**
     * Abstract method that must be implemented by subclasses to define the stacks to be deployed.
     * @param context The resource context containing the scope, stage, environment, and blueprint properties.
     */
    abstract stacks(context: ResourceContext): void;
    /**
     * Getter for the resource context.
     * @returns The resource context containing the scope, stage, environment, and blueprint properties.
     */
    protected get context(): ResourceContext;
    /**
     * Getter for the deployment scope.
     * @returns The deployment scope construct.
     */
    protected get scope(): Construct;
    /**
     * Getter for the deployment environment.
     * @returns The deployment environment.
     */
    protected get env(): cdk.Environment;
    /**
     * Getter for the stage name.
     * @returns The name of the deployment stage.
     */
    protected get stageName(): string;
    /**
     * Getter for the application name.
     * @returns The name of the application being deployed.
     */
    protected get applicationName(): string;
    /**
     * Getter for the application qualifier.
     * @returns The qualifier for the application being deployed.
     */
    protected get applicationQualifier(): string;
    /**
     * Getter for the pipeline configuration properties.
     * @returns The pipeline configuration properties.
     */
    protected get properties(): IPipelineConfig;
    /**
     * Getter for the encryption key.
     * @returns The encryption key used in the deployment.
     */
    protected get encryptionKey(): kms.Key;
    /**
     * Resolves the value of an SSM parameter.
     * @param ssmParameterName The name of the SSM parameter to resolve.
     * @returns The resolved value of the SSM parameter.
     */
    resolve(ssmParameterName: string): string;
}
