import * as cdk from 'aws-cdk-lib';
import * as codebuild from 'aws-cdk-lib/aws-codebuild';
import * as ec2 from 'aws-cdk-lib/aws-ec2';
import * as iam from 'aws-cdk-lib/aws-iam';
import { CodeBuildOptions } from 'aws-cdk-lib/pipelines';
import { IParameterConstruct } from '.';
import { IProxyConfig } from './ProxyProvider';
import { ResourceContext, IResourceProvider, NPMRegistryConfig } from '../common';
/**
 * Interface for a factory that provides CodeBuild options for the pipeline.
 */
export interface ICodeBuildFactory {
    /**
     * Provides the CodeBuild options for the pipeline
     * @returns The CodeBuildOptions object containing options for the CodeBuild project
     */
    provideCodeBuildOptions(): CodeBuildOptions;
}
/**
 * Provides HTTPProxy settings for the pipeline.
 */
export declare class CodeBuildFactoryProvider implements IResourceProvider {
    constructor();
    /**
     * Provides the DefaultCodeBuildFactory instance
     * @param context The ResourceContext object containing blueprint properties and other resources
     * @returns The DefaultCodeBuildFactory instance
     */
    provide(context: ResourceContext): any;
}
export interface DefaultCodeBuildFactoryProps {
    /**
     * The applicationQualifier used for the pipeline.
     */
    readonly applicationQualifier: string;
    /**
     * The AWS region to set.
     */
    readonly region: string;
    /**
     * The account ID of the RES stage
     */
    readonly resAccount: string;
    /**
     * The VPC to use for the CodeBuild project
     * Default value is undefined (no VPC)
     */
    readonly vpc?: ec2.IVpc;
    /**
     * Configuration for an HTTP proxy
     * Default value is undefined
     */
    readonly proxyConfig?: IProxyConfig;
    /**
     * Configuration for an NPM registry
     * Default value is undefined
     */
    readonly npmRegistry?: NPMRegistryConfig;
    /**
     * Environment settings for the CodeBuild project
     * Default value is undefined
     */
    readonly codeBuildEnvSettings?: codebuild.BuildEnvironment;
    /**
     * Provider for Parameter Store parameters
     */
    readonly parameterProvider: IParameterConstruct;
    /**
     * The install commands to run before the build phase
     */
    readonly installCommands?: string[];
    /**
     * Additional IAM policy statements to be added to the CodeBuild project role
     * Default value is undefined
     */
    readonly additionalRolePolicies?: iam.PolicyStatement[];
}
/**
 * Default implementation of the ICodeBuildFactory interface
 * Provides CodeBuild options for the pipeline, including proxy and NPM registry configurations
 */
export declare class DefaultCodeBuildFactory implements ICodeBuildFactory {
    private codeBuildOptions;
    private partialCodeBuildSpec;
    constructor(props: DefaultCodeBuildFactoryProps);
    /**
     * Generates a partial CodeBuild buildspec based on the provided properties
     * @param props The properties used to generate the buildspec
     * @returns The partially constructed buildspec
     */
    protected generatePartialBuildSpec(props: DefaultCodeBuildFactoryProps): cdk.aws_codebuild.BuildSpec;
    /**
     * Generates build environment variables for the CodeBuild project based on the provided proxy configuration
     * @param props The properties containing the proxy configuration
     * @returns An object containing the build environment variables
     */
    protected generateBuildEnvironmentVariables(props: DefaultCodeBuildFactoryProps): Record<string, string>;
    /**
     * Generates install commands for the CodeBuild project based on the provided proxy configuration
     * @param props The properties containing the proxy configuration
     * @returns An array of install commands
     */
    protected generateInstallCommands(props: DefaultCodeBuildFactoryProps): string[];
    /**
     * Generates Secrets Manager values for the CodeBuild project based on the provided proxy configuration
     * @param props The properties containing the proxy configuration
     * @returns An object containing Secrets Manager values
     */
    protected generateCodeBuildSecretsManager(props: DefaultCodeBuildFactoryProps): Record<string, string>;
    /**
     * Generates IAM role policies for the CodeBuild project based on the provided properties
     * @param props The properties containing configuration for the CodeBuild project
     * @returns An array of IAM policy statements
     */
    protected generateRolePolicies(props: DefaultCodeBuildFactoryProps): cdk.aws_iam.PolicyStatement[];
    /**
     * Generates default options for a CodeBuild project in a VPC
     * @param vpc The VPC to use for the CodeBuild project, default is undefined (no VPC)
     * @returns An object containing default options for a CodeBuild project in a VPC
     */
    generateVPCCodeBuildDefaults(vpc?: ec2.IVpc): object;
    /**
     * Provides the CodeBuild options for the pipeline
     * @returns The CodeBuildOptions object containing options for the CodeBuild project
     */
    provideCodeBuildOptions(): CodeBuildOptions;
}
