import { ResourceContext, IResourceProvider, Scope, IPhaseCommand, PipelinePhases } from '../common';
/**
 * Phase command that invokes NPM scripts from project package.json
 */
export declare class NPMPhaseCommand implements IPhaseCommand {
    readonly script: string;
    constructor(script: string);
    /**
     * Returns the command to be executed for the given NPM script.
     */
    get command(): string;
}
/**
 * Phase Command that invokes shell scripts from project folder.
 */
export declare class ShellScriptPhaseCommand implements IPhaseCommand {
    readonly script: string;
    constructor(script: string);
    /**
     * Returns the command to be executed for the given shell script.
     */
    get command(): string;
}
/**
 * Phase Command that invokes a simple shell command.
 */
export declare class ShellCommandPhaseCommand implements IPhaseCommand {
    readonly command: string;
    constructor(command: string);
}
/**
 * Creates a new ShellCommandPhaseCommand instance with the given command.
 * @param command The shell command to be executed.
 * @returns A new ShellCommandPhaseCommand instance.
 */
export declare const sh: (command: string) => ShellCommandPhaseCommand;
/**
 * Phase Command that invokes Python scripts from project folder.
 */
export declare class PythonPhaseCommand implements IPhaseCommand {
    readonly script: string;
    constructor(script: string);
    /**
     * Returns the command to be executed for the given Python script.
     */
    get command(): string;
}
/**
 * Phase Command that place the scripts code directly into the CodeBuild buildSpec definition.
 *
 * This is used to add scripts from this NPM library to the buildSpec that needs to run without internet access or ability to invoke npm ci.
 */
export declare class InlineShellPhaseCommand implements IPhaseCommand {
    readonly script: string;
    /**
     * Determines whether the script should export environment variables or not.
     * @default false
     */
    readonly exportEnvironment: boolean;
    constructor(script: string, 
    /**
     * Determines whether the script should export environment variables or not.
     * @default false
     */
    exportEnvironment?: boolean);
    /**
     * Returns the command to be executed for the given inline shell script.
     */
    get command(): string;
}
/**
 * List of built-in commands that are used on pipelines.
 */
export declare const PhaseCommands: {
    /**
     * This command runs the npm run build script, that builds the source code.
     */
    BUILD: NPMPhaseCommand;
    /**
     * This command executes the CDK synth without look up.
     */
    CDK_SYNTH_NO_LOOK_UP: InlineShellPhaseCommand;
    /**
     * This command executes the CDK synth with look up.
     */
    CDK_SYNTH: InlineShellPhaseCommand;
    /**
     * This command runs the npm run audit script, that audit the dependencies and source codes of the project.
     */
    CHECK_AUDIT: NPMPhaseCommand;
    /**
     * This command runs the npm run lint script, that lints the source code.
     */
    CHECK_LINT: NPMPhaseCommand;
    /**
     * This command configures the HTTP Proxy settings
     */
    CONFIGURE_HTTP_PROXY: InlineShellPhaseCommand;
    /**
     * This command populates build-env variables from the SSM Parameter store.
     */
    ENVIRONMENT_PREPARATION: InlineShellPhaseCommand;
    /**
     * This command installs the NPM dependencies.
     */
    NPM_CI: NPMPhaseCommand;
    /**
     * This command configures NPM authentication for private registries.
     */
    NPM_LOGIN: InlineShellPhaseCommand;
    /**
     * This command runs the npm run test script, that tests the source code.
     */
    TEST: NPMPhaseCommand;
    /**
     * This command runs the npm run validate script, that validates the package-lock.json is not tempered with.
     */
    VALIDATE: NPMPhaseCommand;
};
/**
 * Setting the list of commands for the phases.
 */
export interface IPhaseCommandSettings {
    /**
     * Returns the list of commands for the specified phases.
     * @param phases The phases for which commands are needed.
     * @returns The list of commands for the specified phases.
     */
    getCommands(...phases: PipelinePhases[]): string[];
}
/**
 * Provides the phase commands
 */
export declare class PhaseCommandProvider implements IResourceProvider {
    scope?: Scope | undefined;
    provide(context: ResourceContext): any;
}
