import * as pipelines from 'aws-cdk-lib/pipelines';
import { IConstruct } from 'constructs';
import { RepositoryType, ResourceContext, IResourceProvider, RepositoryConfig } from '../common';
/**
 * Represents a repository stack in the pipeline.
 */
export interface IRepositoryStack extends IConstruct {
    readonly pipelineInput: pipelines.IFileSetProducer;
    readonly pipelineEnvVars: {
        [key: string]: string;
    };
    readonly repositoryBranch: string;
}
/**
 * Provider for repository resources.
 */
export type RepositoryProvider = IResourceProvider;
/**
 * Base properties for repository provider.
 */
export interface BaseRepositoryProviderProps extends RepositoryConfig {
    readonly codeStarConnectionArn?: string;
    readonly codeGuruReviewer?: boolean;
}
/**
 * Basic implementation of repository provider.
 */
export declare class BasicRepositoryProvider implements RepositoryProvider {
    readonly config: BaseRepositoryProviderProps;
    constructor(config?: BaseRepositoryProviderProps);
    /**
     * Provides a repository stack based on the configuration.
     * @param context The resource context.
     * @returns The repository stack.
     */
    provide(context: ResourceContext): any;
}
/**
 * Represents a repository source.
 */
export declare abstract class RepositorySource {
    /**
     * Creates a new CodeCommit repository source.
     *
     * @param options The repository source options.
     * @returns
     */
    static codecommit(options?: CodeCommitRepositorySourceOptions): RepositorySource;
    /**
     * Creates a new Github - CodeStar connection repository source.
     *
     * @param options The repository source options.
     * @returns
     */
    static github(options?: CodeStarConnectionRepositorySourceOptions): RepositorySource;
    /**
     * Creates a new CodeStar connection repository source.
     *
     * @param options The repository source options.
     * @returns
     */
    static codestarConnection(options?: CodeStarConnectionRepositorySourceOptions): RepositorySource;
    static basedType(type: RepositoryType, config?: BaseRepositoryProviderProps): RepositorySource;
    protected constructor();
    abstract produceSourceConfig(context: ResourceContext): IRepositoryStack;
}
export declare class CodeCommitRepositorySource extends RepositorySource {
    private options;
    constructor(options?: CodeCommitRepositorySourceOptions);
    produceSourceConfig(context: ResourceContext): IRepositoryStack;
}
export declare class CodeStarConnectionRepositorySource extends RepositorySource {
    private options;
    constructor(options?: CodeStarConnectionRepositorySourceOptions);
    produceSourceConfig(context: ResourceContext): IRepositoryStack;
}
/**
 * Represents the configuration for a repository source.
 */
export interface RepositorySourceOptions {
    /**
     * The name of the repository.
     * @default - The name of the application.
     *
     * other options to configure:
     * in  package.json file
     *
     * "config": {
     *  "repositoryName": "my-repo",
     * }
     */
    readonly repositoryName?: string;
    /**
     * The branch of the repository.
     * @default - 'main'
     */
    readonly branch?: string;
    /**
     * The description of the repository.
     * @default - No description.
     */
    readonly description?: string;
    /**
     * Enforce full clone for the repository.
     * Tools like semgrep and pre-commit hooks require a full clone.
     *
     * @default - false
     */
    readonly codeBuildCloneOutput?: boolean;
}
export interface CodeCommitRepositorySourceOptions extends RepositorySourceOptions {
    /**
     * Enable pull request checks.
     *
     * @default - true
     */
    readonly enablePullRequestChecks?: boolean;
    /**
     * Enable CodeGuru Reviewer.
     *
     * @default - false
     */
    readonly enableCodeGuruReviewer?: boolean;
}
export interface CodeStarConnectionRepositorySourceOptions extends RepositorySourceOptions {
    /**
     * The ARN of the CodeStar connection.
     *
     * @default - The value of the CODESTAR_CONNECTION_ARN environment variable.
     */
    readonly codeStarConnectionArn?: string;
}
