import * as cdk from 'aws-cdk-lib';
import * as codebuild from 'aws-cdk-lib/aws-codebuild';
import { PipelineOptions } from '../code-pipeline';
import { IPipelineConfig, NPMRegistryConfig, IPhaseCommand, PipelinePhases, IResourceProvider, CodeGuruSeverityThreshold, IStackProvider, IStageDefinition, WorkbenchOptions, IPlugin } from '../common';
import { IProxyConfig } from '../resource-providers/ProxyProvider';
import { RepositoryProvider, RepositorySource } from '../resource-providers/RepositoryProvider';
/**
 * Class for building a Pipeline Blueprint.
 */
export declare class PipelineBlueprintBuilder {
    private props;
    private _id?;
    private stacksCommon;
    private stageDefinitions;
    private stacksByStage;
    private _region?;
    private _plugins;
    /**
     * Constructor for the PipelineBlueprintBuilder class.
     * @param props The configuration properties for the Pipeline Blueprint. Defaults to the `defaultConfigs` object.
     */
    constructor(props?: IPipelineBlueprintProps);
    /**
     * Sets the ID for the Pipeline Blueprint.
     * @param id The ID to set.
     * @returns This PipelineBlueprintBuilder instance.
     */
    id(id: string): this;
    /**
     * Sets the application name for the Pipeline Blueprint.
     * @param applicationName The application name to set.
     * @returns This PipelineBlueprintBuilder instance.
     */
    applicationName(applicationName: string): this;
    /**
     * Sets the NPM registry configuration for the Pipeline Blueprint.
     * @param npmRegistry The NPM registry configuration to set.
     * @returns This PipelineBlueprintBuilder instance.
     */
    npmRegistry(npmRegistry: NPMRegistryConfig): this;
    /**
     * Sets the proxy configuration for the Pipeline Blueprint.
     * @param proxy The proxy configuration to set. If not provided, a default proxy configuration will be used.
     * @returns This PipelineBlueprintBuilder instance.
     */
    proxy(proxy?: IProxyConfig): this;
    /**
     * Sets the application qualifier for the Pipeline Blueprint.
     * @param applicationQualifier The application qualifier to set.
     * @returns This PipelineBlueprintBuilder instance.
     */
    applicationQualifier(applicationQualifier: string): this;
    /**
     * Sets the AWS region for the Pipeline Blueprint.
     * @param region The AWS region to set.
     * @returns This PipelineBlueprintBuilder instance.
     */
    region(region: string): this;
    /**
     * Sets the log retention period in days for the Pipeline Blueprint.
     * @param logRetentionInDays The log retention period in days to set.
     * @returns This PipelineBlueprintBuilder instance.
     */
    logRetentionInDays(logRetentionInDays: string): this;
    /**
     * Sets the CodeBuild environment settings for the Pipeline Blueprint.
     * @param codeBuildEnvSettings The CodeBuild environment settings to set.
     * @returns This PipelineBlueprintBuilder instance.
     */
    codeBuildEnvSettings(codeBuildEnvSettings: codebuild.BuildEnvironment): this;
    /**
     * Sets the Amazon CodeGuru Reviewer severity threshold for the Pipeline Blueprint.
     * @param codeGuruScanThreshold The Amazon CodeGuru Reviewer severity threshold to set.
     * @returns This PipelineBlueprintBuilder instance.
     */
    codeGuruScanThreshold(codeGuruScanThreshold: CodeGuruSeverityThreshold): this;
    /**
     * Sets the repository provider for the Pipeline Blueprint.
     * @param repositoryProvider The repository provider to set.
     * @returns This PipelineBlueprintBuilder instance.
     */
    repositoryProvider(repositoryProvider: RepositoryProvider): this;
    repository(repositorySource: RepositorySource): this;
    /**
     * Sets a resource provider for the Pipeline Blueprint.
     * @param name The name of the resource provider.
     * @param provider The resource provider to set.
     * @returns This PipelineBlueprintBuilder instance.
     */
    resourceProvider(name: string, provider: IResourceProvider): this;
    disable(name: string): this;
    /** Adds a plugin to the Pipeline Blueprint.
     * @param plugin The plugin to add.
     * @returns This PipelineBlueprintBuilder instance.
     */
    plugin(plugin: IPlugin): this;
    /**
     * Defines the pipeline options for the Pipeline Blueprint.
     */
    pipelineOptions(options: PipelineOptions): this;
    /**
     * Defines the primary output directory for the CDK Synth.
     *
     * @default './cdk.out'
     *
     * @param primaryOutputDirectory Configures the primary output directory for the synth step.
     * @returns
     */
    primaryOutputDirectory(primaryOutputDirectory: string): this;
    /**
     * Defines the stages for the Pipeline Blueprint.
     * @param stageDefinition An array of stage definitions or stage names.
     * @returns This PipelineBlueprintBuilder instance.
     */
    defineStages(stageDefinition: (IStageDefinition | string)[]): this;
    /**
     * Adds a stage to the Pipeline Blueprint.
     * @param stage The name of the stage to add.
     * @param account The AWS account ID for the stage.
     * @param region The AWS region for the stage.
     * @returns This PipelineBlueprintBuilder instance.
     */
    private addStage;
    /**
     * Sets up a workbench environment for the Pipeline Blueprint.
     * @param stackProvider The stack provider for the workbench environment.
     * @param option Optional workbench options.
     * @returns This PipelineBlueprintBuilder instance.
     */
    workbench(stackProvider: IStackProvider, option?: WorkbenchOptions): this;
    /**
     * Adds a stack to the Pipeline Blueprint.
     * @param stackProvider The stack provider to add.
     * @param stages The stages to which the stack should be added.
     * @returns This PipelineBlueprintBuilder instance.
     */
    addStack(stackProvider: IStackProvider, ...stages: string[]): this;
    /**
     * Defines a phase for the Pipeline Blueprint.
     * @param phase The phase to define.
     * @param commandsToExecute The commands to execute during the phase.
     * @returns This PipelineBlueprintBuilder instance.
     */
    definePhase(phase: PipelinePhases, commandsToExecute: IPhaseCommand[]): this;
    /**
     * Defines the buildSpec for the Synth step.
     *
     * The buildSpec takes precedence over the definedPhases.
     *
     * Usage:
     *  ```typescript
     *     PipelineBlueprint.builder().buildSpec(BuildSpec.fromObject({ phases: { build: { commands: ['npm run build'] } } }))
     *  ```
     *
     * @param buildSpec - BuildSpec for the Synth step.
     * @returns
     */
    buildSpec(buildSpec: codebuild.BuildSpec): this;
    /**
     * Defines the buildSpec for the Synth step from a file.
     *
     * The buildSpec takes precedence over the definedPhases.
     *
     * Usage:
     *  ```typescript
     *     PipelineBlueprint.builder().buildSpecFromFile('buildspec.yml')
     *  ```
     *
     * @param filePath - Path to the buildspec file.
     * @returns
     */
    buildSpecFromFile(filePath: string): this;
    /**
     * Synthesizes the Pipeline Blueprint and creates the necessary stacks.
     * @param app The CDK app instance.
     * @returns The created stack.
     */
    synth(app: cdk.App): cdk.Stack;
    /**
     * Generates the deployment definitions for the Pipeline Blueprint.
     * @returns The deployment definitions.
     */
    private generateDeploymentDefinitions;
    private generateComplianceLogBucketName;
}
/**
 * Interface for Pipeline Blueprint configuration properties.
 */
export interface IPipelineBlueprintProps extends IPipelineConfig {
    /**
     * Named resource providers to leverage for cluster resources.
     * The resource can represent Vpc, Hosting Zones or other resources, see {@link spi.ResourceType}.
     * VPC for the cluster can be registered under the name of 'vpc' or as a single provider of type
     */
    resourceProviders: {
        [key in string]: IResourceProvider;
    };
    /**
     * The plugins configured for the pipeline
     */
    plugins: Record<string, IPlugin>;
}
/**
 * Class for creating a Pipeline Blueprint.
 */
export declare class PipelineBlueprint {
    /**
     * Creates a new PipelineBlueprintBuilder instance.
     * @returns A PipelineBlueprintBuilder instance.
     */
    static builder(): PipelineBlueprintBuilder;
}
