import * as cdk from 'aws-cdk-lib';
import * as ec2 from 'aws-cdk-lib/aws-ec2';
import { Construct } from 'constructs';
/**
 * Properties for the VPCStack.
 */
export interface ManagedVPCStackProps extends cdk.StackProps {
    /**
     * CIDR block for the VPC.
     */
    readonly cidrBlock: string;
    /**
     * Subnets CIDR masks.
     */
    readonly subnetCidrMask: number;
    /**
     * Max AZs.
     */
    readonly maxAzs: number;
    /**
     * Whether to use a proxy for the VPC.
     * Default value is false.
     */
    readonly useProxy: boolean;
    /**
     * The name of the S3 bucket for VPC flow logs.
     */
    readonly flowLogsBucketName?: string;
    /**
     * If set to true then the default inbound & outbound rules will be removed
     * from the default security group
     *
     * @default true
     */
    readonly restrictDefaultSecurityGroup?: boolean;
    /**
     * Whether to allow all outbound traffic by default.
     *
     * If this is set to true, there will only be a single egress rule which allows all
     * outbound traffic. If this is set to false, no outbound traffic will be allowed by
     * default and all egress traffic must be explicitly authorized.
     *
     * @default true
     */
    readonly allowAllOutbound?: boolean;
    /**
     * The list of CodeBuild VPC InterfacesVpcEndpointAwsServices to extend the defaultCodeBuildVPCInterfaces
     */
    readonly codeBuildVPCInterfaces?: ec2.InterfaceVpcEndpointAwsService[];
    /**
     * The subnets attached to the VPC
     *
     * @default - Private Subnet only
     */
    readonly subnetType?: ec2.SubnetType;
}
/**
 * A stack that creates or looks up a VPC and configures its settings.
 */
export declare class ManagedVPCStack extends cdk.Stack {
    /**
     * The VPC created or looked up by this stack.
     */
    readonly vpc: ec2.IVpc;
    /**
     * The security group attached to the VPC
     */
    private _securityGroup?;
    /**
     * The subnets attached to the VPC
     */
    readonly subnetType?: ec2.SubnetType;
    /**
     * The list of CodeBuild VPC InterfacesVpcEndpointAwsServices
     */
    readonly codeBuildVPCInterfaces: ec2.InterfaceVpcEndpointAwsService[];
    readonly cidrBlock: string;
    readonly restrictDefaultSecurityGroup: boolean;
    readonly allowAllOutbound: boolean;
    readonly subnetCidrMask: number;
    readonly maxAzs: number;
    get securityGroup(): ec2.ISecurityGroup | undefined;
    constructor(scope: Construct, id: string, props: ManagedVPCStackProps);
    /**
     * Launches a VPC with an isolated subnet and configures security groups and VPC endpoints.
     * @param props The properties for configuring the VPC.
     * @returns The created VPC.
     */
    private launchVPCIsolated;
    /**
     * Launches a VPC with a private subnet with egress.
     * @param props The properties for configuring the VPC.
     * @returns The created VPC.
     */
    private launchVPCWithEgress;
}
